@@ -113,8 +113,10 @@ verve_plugin_load_completion (VerveEnv* env, gpointer user_data)
     items = g_list_insert_sorted (items, iter->data, (GCompareFunc) g_utf8_collate);
 
   /* Add merged items to completion */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   if (G_LIKELY (history != NULL)) 
     g_completion_add_items (verve->completion, items);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* Free merged list */
   g_list_free (items);
@@ -444,7 +446,9 @@ verve_plugin_keypress_cb (GtkWidget   *entry,
         G_LOCK (plugin_completion_mutex);
 
         /* Get all completion results */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         similar = g_completion_complete (completion, prefix, NULL);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
         G_UNLOCK (plugin_completion_mutex);
 
@@ -493,11 +497,6 @@ verve_plugin_new (XfcePanelPlugin *plugin)
   /* Set application name */
   g_set_application_name ("Verve");
 
-#if !GLIB_CHECK_VERSION (2, 30, 0)
-  /* Init thread system */
-  g_thread_init (NULL);
-#endif
-
   /* Init Verve mini-framework */
   verve_init ();
   
@@ -509,7 +508,9 @@ verve_plugin_new (XfcePanelPlugin *plugin)
   
   /* Initialize completion variables */
   verve->history_current = NULL;
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   verve->completion = g_completion_new (NULL);
+G_GNUC_END_IGNORE_DEPRECATIONS
   verve->n_complete = 0;
   verve->size = 20;
   verve->history_length = 25;
@@ -587,7 +588,9 @@ verve_plugin_free (XfcePanelPlugin *plugin,
   verve_plugin_focus_timeout_reset (verve);
 
   /* Unload completion */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   g_completion_free (verve->completion);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* Free plugin data structure */
   g_free (verve);
